==> cutefish-terminal-0.4-2.src.tar.gz: terminal-0.4/translations/en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>ExitPromptDialog</name>
    <message>
        <location filename="../src/qml/ExitPromptDialog.qml" line="49"/>
        <source>Process is running, are you sure you want to quit?</source>
        <translation>Process is running, are you sure you want to quit?</translation>
    </message>
    <message>
        <location filename="../src/qml/ExitPromptDialog.qml" line="63"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/qml/ExitPromptDialog.qml" line="57"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>Terminal</name>
    <message>
        <location filename="../src/qml/Terminal.qml" line="171"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/Terminal.qml" line="177"/>
        <location filename="../src/qml/Terminal.qml" line="191"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/Terminal.qml" line="197"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/Terminal.qml" line="202"/>
        <source>Open File Manager</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> cutefish-terminal-0.7-1.src.tar.gz: terminal-0.7/translations/en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>ExitPromptDialog</name>
    <message>
        <location filename="../src/qml/ExitPromptDialog.qml" line="49"/>
        <source>Process is running, are you sure you want to quit?</source>
        <translation>Process is running, are you sure you want to quit?</translation>
    </message>
    <message>
        <location filename="../src/qml/ExitPromptDialog.qml" line="63"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/qml/ExitPromptDialog.qml" line="57"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/qml/SettingsDialog.qml" line="10"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/SettingsDialog.qml" line="39"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/SettingsDialog.qml" line="63"/>
        <source>Font Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/SettingsDialog.qml" line="82"/>
        <source>Transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/SettingsDialog.qml" line="101"/>
        <source>Window Blur</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Terminal</name>
    <message>
        <location filename="../src/qml/Terminal.qml" line="178"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/Terminal.qml" line="184"/>
        <location filename="../src/qml/Terminal.qml" line="198"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/Terminal.qml" line="204"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/Terminal.qml" line="209"/>
        <source>Open File Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/Terminal.qml" line="214"/>
        <source>Exit full screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/Terminal.qml" line="214"/>
        <source>Full screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/qml/Terminal.qml" line="221"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
